Camera Module
=============

.. contents::
    :local:

This module contains a :class:`~emva1288.camera.camera.Camera` simulator
and a :class:`~emva1288.camera.dataset_generator.DatasetGenerator`. The camera
serves to simulate image grabbing. The dataset generator uses the camera
simulator to generate a set of images and a descriptor file to simulate
a complete set of images of an EMVA1288 test.


:mod:`~emva1288.camera.camera`
------------------------------

.. automodule:: emva1288.camera.camera
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__

:mod:`~emva1288.camera.routines`
--------------------------------

.. automodule:: emva1288.camera.routines
    :members:
    :undoc-members:
    :show-inheritance:

:mod:`~emva1288.camera.dataset_generator`
-----------------------------------------

.. automodule:: emva1288.camera.dataset_generator
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__

:mod:`~emva1288.camera.points_generator`
----------------------------------------

.. automodule:: emva1288.camera.points_generator
    :members:
    :undoc-members:
    :show-inheritance:
    :special-members: __init__
